close_channel

Function close_channel 

pub(crate) async fn close_channel(
    __arg0: Path<ChannelIdParams>,
    __arg1: State<Arc<InternalState>>,
) -> impl IntoResponse
Closes the given channel.

If the channel is currently Open, it will transition it to PendingToClose. If the channels are in PendingToClose and the channel closure period has elapsed, it will transition it to Closed.