pub(crate) async fn fund_channel(
__arg0: Path<ChannelIdParams>,
__arg1: State<Arc<InternalState>>,
__arg2: Json<FundBodyRequest>,
) -> impl IntoResponseExpand description
Funds the given channel with the given amount of HOPR tokens.
pub(crate) async fn fund_channel(
__arg0: Path<ChannelIdParams>,
__arg1: State<Arc<InternalState>>,
__arg2: Json<FundBodyRequest>,
) -> impl IntoResponseFunds the given channel with the given amount of HOPR tokens.