pub(crate) async fn open_channel(
__arg0: State<Arc<InternalState>>,
__arg1: Json<OpenChannelBodyRequest>,
) -> impl IntoResponseExpand description
Opens a channel to the given on-chain address with the given initial stake of HOPR tokens.
pub(crate) async fn open_channel(
__arg0: State<Arc<InternalState>>,
__arg1: Json<OpenChannelBodyRequest>,
) -> impl IntoResponseOpens a channel to the given on-chain address with the given initial stake of HOPR tokens.